==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/el.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Έγγραφα",
"Can't create document" => "Δεν είναι δυνατή η δημιουργία του εγγράφου",
"You don't have permission to rename this document" => "Δεν έχετε άδεια να μετονομάσετε αυτό το έγγραφο",
"Directory saved successfully." => "Η βιβλιοθήκη αποθηκεύτηκε επιτυχημένα.",
"An error occurred while changing directory." => "Παρουσιάστηκε ένα πρόβλημα κατά την αλλαγή βιβλιοθήκης.",
"Saved" => "Αποθηκεύτηκαν",
"Format filter server is down or misconfigured" => "Ο διακομιστής μορφών φίλτρων είναι εκτός σύνδεσης ή δεν έχει ρυθμιστεί σωστά",
"Conversion failed. Check log for details." => "Η μετατροπή απέτυχε. Ελέγξτε το αρχείο καταγραφής για λεπτομέρειες.",
"document-styles" => "στυλ-εγγράφων",
"document-content" => "περιεχόμενο-εγγράφων",
"bold" => "έντονα",
"italic" => "πλάγια",
"solid" => "συνεχή",
"pt" => "pt",
"Saving..." => "Γίνεται αποθήκευση...",
"Failed to load documents." => "Αποτυχία φόρτωσης εγγράφων.",
"No documents were found. Upload or create a document to get started!" => "Δεν βρέθηκαν έγγραφα. Μεταφορτώστε ή δημιουργήστε ένα έγγραφο για να αρχίσετε!",
"No connection to server. Trying to reconnect." => "Αποτυχία σύνδεσης με το διακομιστή. Προσπάθεια επανασύνδεσης σε εξέλιξη.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Αποχωρώντας από την κατάσταση Επεξεργασίας της σελίδας μπορεί να υπάρξουν μη αποθηκευμένα δεδομένα. Αντί γι' αυτό, συνίσταται να χρησιμοποιήσετε το κουμπί 'Κλείσιμο'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Αποτυχία φόρτωσης του εγγράφου. Παρακαλώ ελέγξτε εάν μπορεί να ανοίξει με εξωτερικό επεξεργαστή odt. Αυτό επίσης μπορεί να σημαίνει ότι πρόσφατα έχει ακυρωθεί ο διαμοιρασμός ή διαγραφεί.",
"Save" => "Αποθήκευση",
"Loading documents..." => "Φόρτωση εγγράφων...",
"'.' is an invalid file name." => "'.' είναι μη έγκυρο όνομα αρχείου.",
"File name cannot be empty." => "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Μη έγκυρο όνομα, '\\', '/', '<', '>', ':', '\"', '|', '?' και '*' δεν επιτρέπονται.",
"Align Left" => "Στοίχιση στα αριστερά",
"Alignment" => "Στοίχιση",
"Align Right" => "Στοίχιση στα δεξιά",
"Annotate" => "Εισαγωγή σχολίου",
"Background" => "Φόντο",
"Bold" => "Έντονα",
"Bottom" => "Κάτω",
"Cancel" => "Άκυρο",
"Center" => "Κέντρο",
"Clone" => "Κλώνος",
"Clone this Style" => "Κλωνοποίηση αυτού του μοτίβου",
"Close" => "Κλείσιμο",
"Color" => "Χρώμα",
"Create" => "Δημιουργία",
"Decrease Indent" => "Μείωση εσοχής",
"Default Style" => "Προεπιλεγμένη διάταξη",
"Delete" => "Διαγραφή",
"Family" => "Οικογένεια",
"Font" => "Γραμματοσειρά",
"Font Effects" => "Εφέ γραμματοσειράς",
"Format" => "Μορφοποίηση",
"Increase Indent" => "Αύξηση εσοχής",
"Insert Image" => "Εισαγωγή Εικόνας",
"Invite Members" => "Πρόσκληση μελών",
"Italic" => "Πλάγια",
"Justified" => "Στοιχισμένα",
"Justify" => "Στοίχιση",
"Left" => "Αριστερά",
"Loading" => "Φόρτωση",
"Members" => "Μέλη",
"New Name:" => "Νέο Όνομα:",
"OK" => "ΟΚ",
"Open" => "Άνοιγμα",
"Options" => "Επιλογές",
"Paragraph..." => "Παράγραφος",
"Paragraph Styles" => "Διάταξη Παραγράφου",
"Redo" => "Επανάληψη",
"Right" => "Δεξιά",
"Size" => "Μέγεθος",
"Spacing" => "Διαστήματα",
"Strikethrough" => "Διαγραφή",
"Style" => "Διάταξη",
"Text" => "Κείμενο",
"Top" => "Επάνω",
"Underline" => "Υπογράμμιση",
"Undo" => "Αναίρεση",
"Unknown Author" => "Άγνωστος Δημιουργός",
"Edit" => "Επεξεργασία",
"Share" => "Διαμοιρασμός",
"guest" => "Επισκέπτης",
"MS Word support (requires openOffice/libreOffice)" => "Υποστήριξη MS Word (απαιτεί openOffice/libreOffice)",
"Local" => "Τοπικός",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "Το openOffice/libreOffice είναι εγκατεστημένο σε αυτό το διακομιστή. Η διαδρομή στο δυαδικό παρέχεται μέσω του preview_libreoffice_path στο config.php",
"External" => "Εξωτερικός",
"openOffice/libreOffice is installed on external server running a format filter server" => "Το openOffice/libreOffice είναι εγκατεστημένο σε εξωτερικό διακομιστή που εκτελεί ένα διακομιστή φίλτρου μορφοποίησης",
"Disabled" => "Απενεργοποιημένο",
"No MS Word support" => "Καμία υποστήριξη για MS Word",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Διεύθυνση URL διακομιστή",
"Apply and test" => "Εφαρμογή και δοκιμή",
"New document" => "Νέο έγγραφο",
"Upload (max. %s)" => "Διαμοιρασμός (max. %s)",
"Upload" => "Μεταφόρτωση",
"Save new documents to" => "Αποθήκευση νέων εγγράφων σε",
"Wrong password. Please retry." => "Λανθασμένος κωδικός πρόσβασης. Παρακαλώ προσπαθήστε ξανά.",
"Password" => "Συνθηματικό",
"Guest %s" => "Επισκέπτης %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Αυτός ο σύνδεσμος έχει λήξει ή δεν υπήρξε ποτέ. Παρακαλώ επικοινωνήστε με το άτομο που το διαμοιράστηκε μαζί σας για λεπτομέρειες.",
"Advanced feature-set" => "Σύνολο χαρακτηριστικών για προχωρημένους",
"(Unstable)" => "(Ασταθές)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/el.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Έγγραφα",
"Can't create document" => "Δεν είναι δυνατή η δημιουργία του εγγράφου",
"You don't have permission to rename this document" => "Δεν έχετε άδεια να μετονομάσετε αυτό το έγγραφο",
"Directory saved successfully." => "Η βιβλιοθήκη αποθηκεύτηκε επιτυχημένα.",
"An error occurred while changing directory." => "Παρουσιάστηκε ένα πρόβλημα κατά την αλλαγή βιβλιοθήκης.",
"Saved" => "Αποθηκεύτηκαν",
"Format filter server is down or misconfigured" => "Ο διακομιστής μορφών φίλτρων είναι εκτός σύνδεσης ή δεν έχει ρυθμιστεί σωστά",
"Conversion failed. Check log for details." => "Η μετατροπή απέτυχε. Ελέγξτε το αρχείο καταγραφής για λεπτομέρειες.",
"Saving..." => "Γίνεται αποθήκευση...",
"Failed to load documents." => "Αποτυχία φόρτωσης εγγράφων.",
"No documents were found. Upload or create a document to get started!" => "Δεν βρέθηκαν έγγραφα. Μεταφορτώστε ή δημιουργήστε ένα έγγραφο για να αρχίσετε!",
"No connection to server. Trying to reconnect." => "Αποτυχία σύνδεσης με το διακομιστή. Προσπάθεια επανασύνδεσης σε εξέλιξη.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Αποχωρώντας από την κατάσταση Επεξεργασίας της σελίδας μπορεί να υπάρξουν μη αποθηκευμένα δεδομένα. Αντί γι' αυτό, συνίσταται να χρησιμοποιήσετε το κουμπί 'Κλείσιμο'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Αποτυχία φόρτωσης του εγγράφου. Παρακαλώ ελέγξτε εάν μπορεί να ανοίξει με εξωτερικό επεξεργαστή odt. Αυτό επίσης μπορεί να σημαίνει ότι πρόσφατα έχει ακυρωθεί ο διαμοιρασμός ή διαγραφεί.",
"Save" => "Αποθήκευση",
"Loading documents..." => "Φόρτωση εγγράφων...",
"'.' is an invalid file name." => "'.' είναι μη έγκυρο όνομα αρχείου.",
"File name cannot be empty." => "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Μη έγκυρο όνομα, '\\', '/', '<', '>', ':', '\"', '|', '?' και '*' δεν επιτρέπονται.",
"Align Left" => "Στοίχιση στα αριστερά",
"Alignment" => "Στοίχιση",
"Align Right" => "Στοίχιση στα δεξιά",
"Annotate" => "Εισαγωγή σχολίου",
"Background" => "Φόντο",
"Bold" => "Έντονα",
"Bottom" => "Κάτω",
"Cancel" => "Άκυρο",
"Center" => "Κέντρο",
"Clone" => "Κλώνος",
"Clone this Style" => "Κλωνοποίηση αυτού του μοτίβου",
"Close" => "Κλείσιμο",
"Color" => "Χρώμα",
"Create" => "Δημιουργία",
"Decrease Indent" => "Μείωση εσοχής",
"Default Style" => "Προεπιλεγμένη διάταξη",
"Delete" => "Διαγραφή",
"Family" => "Οικογένεια",
"Font" => "Γραμματοσειρά",
"Font Effects" => "Εφέ γραμματοσειράς",
"Format" => "Μορφοποίηση",
"Increase Indent" => "Αύξηση εσοχής",
"Insert Image" => "Εισαγωγή Εικόνας",
"Invite Members" => "Πρόσκληση μελών",
"Italic" => "Πλάγια",
"Justified" => "Στοιχισμένα",
"Justify" => "Στοίχιση",
"Left" => "Αριστερά",
"Loading" => "Φόρτωση",
"Members" => "Μέλη",
"New Name:" => "Νέο Όνομα:",
"OK" => "ΟΚ",
"Open" => "Άνοιγμα",
"Options" => "Επιλογές",
"Paragraph..." => "Παράγραφος",
"Paragraph Styles" => "Διάταξη Παραγράφου",
"Redo" => "Επανάληψη",
"Right" => "Δεξιά",
"Size" => "Μέγεθος",
"Spacing" => "Διαστήματα",
"Strikethrough" => "Διαγραφή",
"Style" => "Διάταξη",
"Text" => "Κείμενο",
"Top" => "Επάνω",
"Underline" => "Υπογράμμιση",
"Undo" => "Αναίρεση",
"Unknown Author" => "Άγνωστος Δημιουργός",
"Shared" => "Κοινόχρηστα",
"Error" => "Σφάλμα",
"Error while sharing" => "Σφάλμα κατά τον διαμοιρασμό",
"Error while unsharing" => "Σφάλμα κατά το σταμάτημα του διαμοιρασμού",
"Error while changing permissions" => "Σφάλμα κατά την αλλαγή των δικαιωμάτων",
"Shared with you and the group {group} by {owner}" => "Διαμοιράστηκε με σας και με την ομάδα {group} του {owner}",
"Shared with you by {owner}" => "Διαμοιράστηκε με σας από τον {owner}",
"Share with users or groups …" => "Διαμοιρασμός με χρήστες ή ομάδες ...",
"Share with users, groups or remote users …" => "Διαμοιρασμός με χρήστες, ομάδες ή απομακρυσμένους χρήστες ...",
"Share" => "Διαμοιρασμός",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Διαμοιρασμός με άτομα σε άλλα ownClouds χρησιμοποιώντας την σύνταξη username@example.com/owncloud",
"Share link" => "Διαμοιρασμός συνδέσμου",
"The public link will expire no later than {days} days after it is created" => "Ο δημόσιος σύνδεσμος θα απενεργοποιηθεί το πολύ {days} ημέρες μετά την δημιουργία του",
"Link" => "Σύνδεσμος",
"Password protect" => "Προστασία συνθηματικού",
"Password" => "Συνθηματικό",
"Choose a password for the public link" => "Επιλέξτε κωδικό για τον δημόσιο σύνδεσμο",
"Allow editing" => "Επιτρέπεται η επεξεργασία",
"Email link to person" => "Αποστολή συνδέσμου με email ",
"Send" => "Αποστολή",
"Set expiration date" => "Ορισμός ημ. λήξης",
"Expiration" => "Λήξη",
"Expiration date" => "Ημερομηνία λήξης",
"An error occured. Please try again" => "Ένα σφάλμα προέκυψε. Παρακαλώ προσπαθήστε ξανά",
"Adding user..." => "Προσθήκη χρήστη ...",
"group" => "ομάδα",
"remote" => "απομακρυσμένα",
"Resharing is not allowed" => "Ξαναμοιρασμός δεν επιτρέπεται",
"Shared in {item} with {user}" => "Διαμοιρασμός του {item} με τον {user}",
"Unshare" => "Διακοπή διαμοιρασμού",
"notify by email" => "ειδοποίηση με email",
"can share" => "δυνατότητα διαμοιρασμού",
"can edit" => "δυνατότητα επεξεργασίας",
"access control" => "έλεγχος πρόσβασης",
"create" => "δημιουργία",
"change" => "αλλαγή",
"delete" => "διαγραφή",
"Password protected" => "Προστασία με συνθηματικό",
"Error unsetting expiration date" => "Σφάλμα κατά την διαγραφή της ημ. λήξης",
"Error setting expiration date" => "Σφάλμα κατά τον ορισμό ημ. λήξης",
"Sending ..." => "Αποστολή...",
"Email sent" => "Το Email απεστάλη ",
"Warning" => "Προειδοποίηση",
"Edit" => "Επεξεργασία",
"guest" => "Επισκέπτης",
"MS Word support (requires openOffice/libreOffice)" => "Υποστήριξη MS Word (απαιτεί openOffice/libreOffice)",
"Local" => "Τοπικός",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "Το openOffice/libreOffice είναι εγκατεστημένο σε αυτό το διακομιστή. Η διαδρομή στο δυαδικό παρέχεται μέσω του preview_libreoffice_path στο config.php",
"External" => "Εξωτερικός",
"openOffice/libreOffice is installed on external server running a format filter server" => "Το openOffice/libreOffice είναι εγκατεστημένο σε εξωτερικό διακομιστή που εκτελεί ένα διακομιστή φίλτρου μορφοποίησης",
"Disabled" => "Απενεργοποιημένο",
"No MS Word support" => "Καμία υποστήριξη για MS Word",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Διεύθυνση URL διακομιστή",
"Apply and test" => "Εφαρμογή και δοκιμή",
"New document" => "Νέο έγγραφο",
"Upload (max. %s)" => "Διαμοιρασμός (max. %s)",
"Upload" => "Μεταφόρτωση",
"Save new documents to" => "Αποθήκευση νέων εγγράφων σε",
"Wrong password. Please retry." => "Λανθασμένος κωδικός πρόσβασης. Παρακαλώ προσπαθήστε ξανά.",
"Guest %s" => "Επισκέπτης %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Αυτός ο σύνδεσμος έχει λήξει ή δεν υπήρξε ποτέ. Παρακαλώ επικοινωνήστε με το άτομο που το διαμοιράστηκε μαζί σας για λεπτομέρειες.",
"Advanced feature-set" => "Σύνολο χαρακτηριστικών για προχωρημένους",
"(Unstable)" => "(Ασταθές)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
